@@ -287,7 +287,8 @@ class GSuiteAddOnsAsyncClient:
         Args:
             request (Optional[Union[google.cloud.gsuiteaddons_v1.types.GetAuthorizationRequest, dict]]):
                 The request object. Request message to get Google
-                Workspace Add-ons authorization information.
+                Workspace Add-ons authorization
+                information.
             name (:class:`str`):
                 Required. Name of the project for which to get the
                 Google Workspace Add-ons authorization information.
